aboutsummaryrefslogtreecommitdiffstats
path: root/tools/search_google.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/search_google.sh')
-rwxr-xr-xtools/search_google.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/search_google.sh b/tools/search_google.sh
index 94a6789..8e82f89 100755
--- a/tools/search_google.sh
+++ b/tools/search_google.sh
@@ -6,14 +6,14 @@ set -e
# @env GOOGLE_API_KEY! The api key
# @env GOOGLE_CSE_ID! The id of google search engine
# @env GOOGLE_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {
encoded_query="$(jq -nr --arg q "$argc_query" '$q|@uri')"
url="https://www.googleapis.com/customsearch/v1?key=$GOOGLE_API_KEY&cx=$GOOGLE_CSE_ID&q=$encoded_query"
curl -fsSL "$url" | \
- jq '[.items[:'"$GOOGLE_MAX_RESULTS"'] | .[] | {title: .title, link: .link, snippet: .snippet}]' \
+ jq '[.items[:'"$SEARCH_MAX_RESULTS"'] | .[] | {link: .link, title: .title, snippet: .snippet}]' \
>> "$LLM_OUTPUT"
}
@@ -6,14 +6,14 @@ set -e
# @env GOOGLE_API_KEY! The api key
# @env GOOGLE_CSE_ID! The id of google search engine
-# @env GOOGLE_MAX_RESULTS=5 The max results to return.
+# @env SEARCH_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {